%global commit b1de4cd146f73e9a679682e209de1ecde1ca094e
%global shortcommit %(c=%{commit}; echo ${c:0:7})

# mingw is x86_64 only on EL9
%if 0%{?rhel} >= 9
%ifarch x86_64
%bcond_without mingw
%else
%bcond_with mingw
%endif
%else
%bcond_without mingw
%endif

Name:           liblerc
Version:        3.1
Release:        0.2%{?commit:.git%{shortcommit}}%{?dist}
Summary:        Library for Limited Error Raster Compression

License:        ASL 2.0
URL:            https://github.com/Esri/lerc
%if 0%{?commit:1}
Source0:        https://github.com/Esri/lerc/archive/%{commit}/lerc-%{shortcommit}.tar.gz
%else
Source0:        https://github.com/Esri/lerc/archive/v%{version}/lerc-%{version}.tar.gz
%endif
# Add version suffix to mingw dll
Patch0:         lerc-dllver.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  python3-devel

%if %{with mingw}
BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
%endif

%description
LERC is an open-source image or raster format which supports rapid encoding and
decoding for any pixel type (not just RGB or Byte). Users set the maximum
compression error per pixel while encoding, so the precision of the original
input image is preserved (within user defined error bounds).


%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%if %{with mingw}
%package -n mingw32-%{name}
Summary:       MinGW Windows %{name} library
BuildArch:     noarch

%description -n mingw32-%{name}
%{summary}.


%package -n mingw64-%{name}
Summary:       MinGW Windows %{name} library
BuildArch:     noarch

%description -n mingw64-%{name}
%{summary}.
%endif


%prep
%if 0%{?commit:1}
%autosetup -p1 -n lerc-%{commit}
%else
%autosetup -p1 -n lerc-v%{version}
%endif

# Fix line endings
sed -i 's/\r$//' NOTICE README.md doc/MORE.md


%build
# Native build
%cmake
%cmake_build

%if %{with mingw}
# MinGW build
%mingw_cmake
%mingw_make_build
%endif


%install
%cmake_install
%if %{with mingw}
%mingw_make_install
%endif


%files
%license LICENSE
%doc README.md CHANGELOG.md NOTICE
%{_libdir}/libLerc.so.3

%files devel
%doc doc/*
%{_includedir}/Lerc_c_api.h
%{_includedir}/Lerc_types.h
%{_libdir}/libLerc.so
%{_libdir}/pkgconfig/Lerc.pc

%if %{with mingw}
%files -n mingw32-%{name}
%license LICENSE
%{mingw32_bindir}/libLerc-3.dll
%{mingw32_includedir}/Lerc_c_api.h
%{mingw32_includedir}/Lerc_types.h
%{mingw32_libdir}/libLerc.dll.a
%{mingw32_libdir}/pkgconfig/Lerc.pc

%files -n mingw64-%{name}
%license LICENSE
%{mingw64_bindir}/libLerc-3.dll
%{mingw64_includedir}/Lerc_c_api.h
%{mingw64_includedir}/Lerc_types.h
%{mingw64_libdir}/libLerc.dll.a
%{mingw64_libdir}/pkgconfig/Lerc.pc
%endif


%changelog
* Fri Jun 10 2022 Orion Poplawski <orion@nwra.com> - 3.1-0.2.gitb1de4cd
- Drop mingw for non-x86_64 on EL9

* Fri May 06 2022 Sandro Mani <manisandro@gmail.com> - 3.1-0.1.gitb1de4cd
- Initial package b1de4cd
